@@ -117,6 +117,10 @@ async def _sync_objects(model, company_uuid, source, bss_objs, model_objs, creat
                                     sbval = set([ip_network(x) for x in sbval])
                                 if smval != sbval:
                                     achgs.append(f"{sf.name}[{smval}->{sbval}]")
+                        elif bval and not mval:
+                            achgs = [f"null->{bval}"]
+                        elif mval and not bval:
+                            achgs = [f"{bval}->null"]
                         if not achgs:
                             continue  # no further inspection, not actually a diff
                         changes.append(f'{f}: {",".join(achgs)}')
