@@ -1147,6 +1147,27 @@ class TestModelSync(unittest.TestCase):
             self.assertEqual(self.model._services[msvc.company_uuid][msvc.uuid].attachment.network_prefixes[0], "192.0.2.101/32")
         self._await(test())
 
+    def test_service_null_attachment(self):
+        """If the service attachment was not set, it can be set by the sync."""
+        async def test():
+            # create a service
+            accounts = {'acct01': Account('acct01', None, AccountStatus.ACCOUNT_STATUS_ACTIVE, 'Account 1', None, None)}
+            packages = {'pkg01': Package('pkg01', 'Package 1', 25000, 5000)}
+            service = Service('service01', account_id='acct01', package_id='pkg01', download_rate=100000, upload_rate=20000, subscriber_identifier='account01', url='https://my.source.url')
+            services = {'service01': service}
+            await sync_preseem_model(self.model, self.company.uuid, 'test_source', ElementRole.AP, [], accounts=accounts, packages=packages, services=services)
+            await self.checkSourceService(service)
+            model_services = await self.model.Service.List(company_uuid=self.company.uuid)
+            msvc = model_services[0]
+            self.model._services[msvc.company_uuid][msvc.uuid].attachment = None
+
+            service = Service('service01', account_id='acct01', package_id='pkg01', download_rate=100000, upload_rate=20000, subscriber_identifier='account01', url='https://my.source.url')
+            service.attachment.mac_addresses.append('00:01:02:03:04:05')
+            services = {'service01': service}
+            await sync_preseem_model(self.model, self.company.uuid, 'test_source', ElementRole.AP, [], accounts=accounts, packages=packages, services=services)
+            await self.checkSourceService(service)
+        self._await(test())
+
     async def checkSourceRouter(self, sobj):
         sites = {}
         for site in await self.model.Site.List(company_uuid=self.company.uuid):
@@ -1201,7 +1222,6 @@ class TestModelSync(unittest.TestCase):
             router.host = '192.0.2.254'
             await sync_preseem_model(self.model, self.company.uuid, 'test_source', ElementRole.AP, [], routers=routers)
             await self.checkSourceRouter(router)
-            print(await self.model.Element.ListElementDiscovery(company_uuid=self.company.uuid))
         self._await(test())
 
     def test_router_update(self):
@@ -1218,7 +1238,6 @@ class TestModelSync(unittest.TestCase):
             router.host = '192.0.2.254'
             await sync_preseem_model(self.model, self.company.uuid, 'test_source', ElementRole.AP, [], routers=routers)
             await self.checkSourceRouter(router)
-            print(await self.model.Element.ListElementDiscovery(company_uuid=self.company.uuid))
         self._await(test())
 
     def test_router_update_error(self):
